@@ -29,7 +29,7 @@ $mypath = "/home/luca/t" ;# path of the directory in which you are going to work
 $file = "t";  # the root model directory.
 
 %dowhat = ( # This variables tells to the program what to do.
-morph => "n", # create cases for simulation?
+morph => "y", # create cases for simulation?
 simulate => "y", # simulate AND retrieve? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
 retrieve => "y",  # retrieve data? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
 report => "y",  # retrieve data? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
@@ -39,9 +39,9 @@ substitutenames => "n", # substitute names (convert) in non-filtered reports? (U
 filterconverted => "n", # filter already converted reports? (UNTESTED SINCE EARLY VERSIONS.)
 make3dtable => "n", # make table to be plotted in 3D? (UNTESTED SINCE EARLY VERSIONS.)
 overwrite_models => { 1 => "n" },
-inactivatemorph => "y",
-inactivatesim => "y",
-inactivateres => "y",
+inactivatemorph => "n",
+inactivatesim => "n",
+inactivateres => "n",
 incativateret => "n",
 actonexisting_models => { 1 => "y" },
 simtools => { 1 => "esp-r", 
