@@ -63,7 +63,7 @@ $simnetwork @themereports %simtitles %reporttitles %retrievedata
 $target %dowhat 
 );
 
-$VERSION = '0.51.01'; # our $VERSION = '';
+$VERSION = '0.51.03'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT is an optimization and morphing program that can be used with simulation programs receiving text files as input and emitting text files as output. It adopts the block coordinate descent optimization method.';
 
 #################################################################################
@@ -1188,9 +1188,6 @@ Where Sim::OPT may be fit for a task? Where a certain exploration is complex and
 
 Where it may not be suitable for the task? For quick shots at small explorations.
 
-Gian Luca Brunetti
-
-gianluca.brunetti@polimi.it
 
 =head2 EXPORT
 
@@ -1198,7 +1195,7 @@ gianluca.brunetti@polimi.it
 
 =head1 SEE ALSO
 
-Examples can be found in the "examples" directory in this distribution.
+Annotated examples can be found in the "examples" directory in this distribution. They constitute the available documentation. Additionally, reference to the source code may be made.
 
 =head1 AUTHOR
 
