@@ -41,7 +41,7 @@ use warnings::unused;
 our @EXPORT = qw( descend ); # our @EXPORT = qw( );
 
 $VERSION = '0.43.11'; # our $VERSION = '';
-
+$ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent.';
 
 #########################################################################################
 # HERE FOLLOWS THE CONTENT OF "Descend.pm" - Sim::OPT::Descend
@@ -596,3 +596,39 @@ sub descend
 }    # END SUB descend
 
 1;
+
+__END__
+
+=head1 NAME
+
+Sim::OPT.
+
+=head1 SYNOPSIS
+
+  use Sim::OPT;
+  opt;
+
+=head1 DESCRIPTION
+
+Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent. It closes the loop formed by Sim::OPT -> Sim::OPT::Morph -> Sim::OPT::Sim -> Sim::OPT::Report::retrieve -> Sim::OPT::Report::report -> Sim::OPT::Descent -> Sim::OPT, which repeats at every block search cycle. It is a circularly recursive loop. 
+
+The objective function for rating the performances of the candidate solutions can be obtained by weighting objective functions (performance indicators) derived by the Sim::OPT::Report module.
+
+=head2 EXPORT
+
+"descend".
+
+=head1 SEE ALSO
+
+Annotated examples can be found in the "examples" directory in this distribution. They constitute the available documentation. Additionally, reference to the source code may be made.
+
+=head1 AUTHOR
+
+Gian Luca Brunetti, E<lt>gianluca.brunetti@polimi.itE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2008-2015 by Gian Luca Brunetti and Politecnico di Milano. This is free software. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2 or later.
+
+
+=cut
