@@ -43,6 +43,7 @@ our @ISA = qw(Exporter); # our @adamkISA = qw(Exporter);
 
 @EXPORT = qw( parcoord3d ); # our @EXPORT = qw( );
 $VERSION = '0.01'; 
+$ABSTRACT = 'Sim::OPT::Parcoord3d is a program that can process the CSV data for a bi-dimensional parallel coordinate plot and output an Autolisp file for a 3D parallel coordinate plot.';
 
 #########################################################################################
 # HERE FOLLOWS THE CONTENT OF "Parcoord3d.pm", Sim::OPT::Parcoord3d
@@ -508,8 +509,6 @@ The objective function to be represented through colours in the parallel coordin
 
 The variables to be specified in the configuration file are described in the comments in the "Sim::OPT" configuration file included in the "examples" folder in this distribution. 
 
-Gian Luca Brunetti, Politecnico di Milano
-gianluca.brunetti@polimi.it
 
 =head2 EXPORT
 
@@ -517,7 +516,7 @@ gianluca.brunetti@polimi.it
 
 =head1 SEE ALSO
 
-The available examples are collected in the "example" directory in this distribution.
+An example can be found in the "examples" directory in this distribution. Especially, reference to the source code should be made.
 
 =head1 AUTHOR
 
@@ -530,3 +529,5 @@ Copyright (C) 2015 by Gian Luca Brunetti and Politecnico di Milano. This is free
 
 =cut
 
+
+
