@@ -37,8 +37,8 @@ use warnings::unused;
 
 our @EXPORT = qw( retrieve report get_files );
 
-$VERSION = '0.50.20'; # our $VERSION = '';
-
+$VERSION = '0.50.21'; # our $VERSION = '';
+$ABSTRACT = 'Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results.';
 
 #########################################################################################
 # HERE FOLLOWS THE CONTENT OF "Retrieve.pm", Sim::OPT::Retrieve
@@ -1357,3 +1357,37 @@ sub get_files # UNUSED. LEGACY. CUT.
 } # END SUB get_files
 
 1;
+
+__END__
+
+=head1 NAME
+
+Sim::OPT.
+
+=head1 SYNOPSIS
+
+  use Sim::OPT;
+  opt;
+
+=head1 DESCRIPTION
+
+Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results. Sim::OPT::Report performs two kinds of action. The first, which is required only by certain simulation programs, is that of managing the simulation program to make it write the results in a user-specified text format. This functionality is platform-specific and is presently implemented only for ESP-r. EnergyPlus does not require this functionality. New lines of code may have to be written for other platforms. The second functionality is that of gathering the results in a user-specified manner. This functionality is based on pattern-matching and is not platform-specific.
+
+=head2 EXPORT
+
+"opt".
+
+=head1 SEE ALSO
+
+Annotated examples can be found in the "examples" directory in this distribution. They constitute the available documentation. Additionally, reference to the source code may be made.
+
+=head1 AUTHOR
+
+Gian Luca Brunetti, E<lt>gianluca.brunetti@polimi.itE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2008-2015 by Gian Luca Brunetti and Politecnico di Milano. This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2 or later.
+
+
+=cut
