@@ -43,8 +43,8 @@ use warnings::unused;
 
 our @EXPORT = qw( sim ); # our @EXPORT = qw( );
 
-$VERSION = '0.49.0'; # our $VERSION = '';
-
+$VERSION = '0.49.1'; # our $VERSION = '';
+$ABSTRACT = 'Sim::OPT::Sim is the module used by Sim::OPT to launch simulations once the models have been built.'; 
 
 #########################################################################################
 # HERE FOLLOWS THE CONTENT OF "Sim.pm", Sim::OPT::Sim
@@ -564,4 +564,38 @@ $printthis
 ##############################################################################
 			
 1;			
-			
+
+
+__END__
+
+=head1 NAME
+
+Sim::OPT.
+
+=head1 SYNOPSIS
+
+  use Sim::OPT;
+  opt;
+
+=head1 DESCRIPTION
+
+Sim::OPT::Sim is the module used by Sim::OPT to launch the simulation once the models have been built. Sim::OPT::Sim's existing functionalities can be used to launch simulations in ESP-r and EnergyPlus. The possibility to call programs other from those two may be pursued through (small or substantial, depending from situation) modifications of the lines of code dedicated to the EnergyPlus platform.
+
+=head2 EXPORT
+
+"opt".
+
+=head1 SEE ALSO
+
+Annotated examples can be found in the "examples" directory in this distribution. They constitute the available documentation. Additionally, reference to the source code may be made.
+
+=head1 AUTHOR
+
+Gian Luca Brunetti, E<lt>gianluca.brunetti@polimi.itE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2008-2015 by Gian Luca Brunetti and Politecnico di Milano. This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2 or later.
+
+
+=cut
